/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.envmonitor.historydata.rest;

import me.zhengjie.annotation.Log;
import me.zhengjie.modules.dm.envmonitor.historydata.domain.DmEnvHistoryData;
import me.zhengjie.modules.dm.envmonitor.historydata.service.DmEnvHistoryDataService;
import me.zhengjie.modules.dm.envmonitor.historydata.service.dto.DmEnvHistoryDataQueryCriteria;
import org.springframework.data.domain.Pageable;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

/**
* @website https://el-admin.vip
* @author lr
* @date 2022-05-19
**/
@RestController
@RequiredArgsConstructor
@Api(tags = "历史数据管理")
@RequestMapping("/api/dmEnvHistoryData")
public class DmEnvHistoryDataController {

    private final DmEnvHistoryDataService dmEnvHistoryDataService;

    @Log("导出数据")
    @ApiOperation("导出数据")
    @GetMapping(value = "/download")
    @PreAuthorize("@el.check('dmEnvHistoryData:list')")
    public void download(HttpServletResponse response, DmEnvHistoryDataQueryCriteria criteria) throws IOException {
        dmEnvHistoryDataService.download(dmEnvHistoryDataService.queryAll(criteria), response);
    }

    @GetMapping
    @Log("查询历史数据")
    @ApiOperation("查询历史数据")
    @PreAuthorize("@el.check('dmEnvHistoryData:list')")
    public ResponseEntity<Object> query(DmEnvHistoryDataQueryCriteria criteria, Pageable pageable){
        return new ResponseEntity<>(dmEnvHistoryDataService.queryAll(criteria,pageable),HttpStatus.OK);
    }

    @PostMapping
    @Log("新增历史数据")
    @ApiOperation("新增历史数据")
    @PreAuthorize("@el.check('dmEnvHistoryData:add')")
    public ResponseEntity<Object> create(@Validated @RequestBody DmEnvHistoryData resources){
        return new ResponseEntity<>(dmEnvHistoryDataService.create(resources),HttpStatus.CREATED);
    }

    @PutMapping
    @Log("修改历史数据")
    @ApiOperation("修改历史数据")
    @PreAuthorize("@el.check('dmEnvHistoryData:edit')")
    public ResponseEntity<Object> update(@Validated @RequestBody DmEnvHistoryData resources){
        dmEnvHistoryDataService.update(resources);
        return new ResponseEntity<>(HttpStatus.NO_CONTENT);
    }

    @Log("删除历史数据")
    @ApiOperation("删除历史数据")
    @PreAuthorize("@el.check('dmEnvHistoryData:del')")
    @DeleteMapping
    public ResponseEntity<Object> delete(@RequestBody Long[] ids) {
        dmEnvHistoryDataService.deleteAll(ids);
        return new ResponseEntity<>(HttpStatus.OK);
    }
}