/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.envmonitor.historymodbusdata.rest;

import me.zhengjie.annotation.Log;
import me.zhengjie.modules.dm.envmonitor.historymodbusdata.domain.DmEnvHistoryModbusData;
import me.zhengjie.modules.dm.envmonitor.historymodbusdata.service.DmEnvHistoryModbusDataService;
import me.zhengjie.modules.dm.envmonitor.historymodbusdata.service.dto.DmEnvHistoryModbusDataQueryCriteria;
import org.springframework.data.domain.Pageable;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

/**
* @website https://el-admin.vip
* @author wld
* @date 2022-05-24
**/
@RestController
@RequiredArgsConstructor
@Api(tags = "管理modbus获取的数据管理")
@RequestMapping("/api/dmEnvHistoryModbusData")
public class DmEnvHistoryModbusDataController {

    private final DmEnvHistoryModbusDataService dmEnvHistoryModbusDataService;

    @Log("导出数据")
    @ApiOperation("导出数据")
    @GetMapping(value = "/download")
    @PreAuthorize("@el.check('dmEnvHistoryModbusData:list')")
    public void download(HttpServletResponse response, DmEnvHistoryModbusDataQueryCriteria criteria) throws IOException {
        dmEnvHistoryModbusDataService.download(dmEnvHistoryModbusDataService.queryAll(criteria), response);
    }

    @GetMapping
    @Log("查询管理modbus获取的数据")
    @ApiOperation("查询管理modbus获取的数据")
    @PreAuthorize("@el.check('dmEnvHistoryModbusData:list')")
    public ResponseEntity<Object> query(DmEnvHistoryModbusDataQueryCriteria criteria, Pageable pageable){
        return new ResponseEntity<>(dmEnvHistoryModbusDataService.queryAll(criteria,pageable),HttpStatus.OK);
    }

    @PostMapping
    @Log("新增管理modbus获取的数据")
    @ApiOperation("新增管理modbus获取的数据")
    @PreAuthorize("@el.check('dmEnvHistoryModbusData:add')")
    public ResponseEntity<Object> create(@Validated @RequestBody DmEnvHistoryModbusData resources){
        return new ResponseEntity<>(dmEnvHistoryModbusDataService.create(resources),HttpStatus.CREATED);
    }

    @PutMapping
    @Log("修改管理modbus获取的数据")
    @ApiOperation("修改管理modbus获取的数据")
    @PreAuthorize("@el.check('dmEnvHistoryModbusData:edit')")
    public ResponseEntity<Object> update(@Validated @RequestBody DmEnvHistoryModbusData resources){
        dmEnvHistoryModbusDataService.update(resources);
        return new ResponseEntity<>(HttpStatus.NO_CONTENT);
    }

    @Log("删除管理modbus获取的数据")
    @ApiOperation("删除管理modbus获取的数据")
    @PreAuthorize("@el.check('dmEnvHistoryModbusData:del')")
    @DeleteMapping
    public ResponseEntity<Object> delete(@RequestBody Long[] ids) {
        dmEnvHistoryModbusDataService.deleteAll(ids);
        return new ResponseEntity<>(HttpStatus.OK);
    }
}