/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.envmonitor.historymodbusdata.service.impl;

import me.zhengjie.modules.dm.envmonitor.historymodbusdata.domain.DmEnvHistoryModbusData;
import me.zhengjie.utils.ValidationUtil;
import me.zhengjie.utils.FileUtil;
import lombok.RequiredArgsConstructor;
import me.zhengjie.modules.dm.envmonitor.historymodbusdata.repository.DmEnvHistoryModbusDataRepository;
import me.zhengjie.modules.dm.envmonitor.historymodbusdata.service.DmEnvHistoryModbusDataService;
import me.zhengjie.modules.dm.envmonitor.historymodbusdata.service.dto.DmEnvHistoryModbusDataDto;
import me.zhengjie.modules.dm.envmonitor.historymodbusdata.service.dto.DmEnvHistoryModbusDataQueryCriteria;
import me.zhengjie.modules.dm.envmonitor.historymodbusdata.service.mapstruct.DmEnvHistoryModbusDataMapper;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import cn.hutool.core.lang.Snowflake;
import cn.hutool.core.util.IdUtil;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import me.zhengjie.utils.PageUtil;
import me.zhengjie.utils.QueryHelp;
import java.util.List;
import java.util.Map;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.LinkedHashMap;

/**
* @website https://el-admin.vip
* @description 服务实现
* @author wld
* @date 2022-05-24
**/
@Service
@RequiredArgsConstructor
public class DmEnvHistoryModbusDataServiceImpl implements DmEnvHistoryModbusDataService {

    private final DmEnvHistoryModbusDataRepository dmEnvHistoryModbusDataRepository;
    private final DmEnvHistoryModbusDataMapper dmEnvHistoryModbusDataMapper;

    @Override
    public Map<String,Object> queryAll(DmEnvHistoryModbusDataQueryCriteria criteria, Pageable pageable){
        Page<DmEnvHistoryModbusData> page = dmEnvHistoryModbusDataRepository.findAll((root, criteriaQuery, criteriaBuilder) -> QueryHelp.getPredicate(root,criteria,criteriaBuilder),pageable);
        return PageUtil.toPage(page.map(dmEnvHistoryModbusDataMapper::toDto));
    }

    @Override
    public List<DmEnvHistoryModbusDataDto> queryAll(DmEnvHistoryModbusDataQueryCriteria criteria){
        return dmEnvHistoryModbusDataMapper.toDto(dmEnvHistoryModbusDataRepository.findAll((root, criteriaQuery, criteriaBuilder) -> QueryHelp.getPredicate(root,criteria,criteriaBuilder)));
    }

    @Override
    @Transactional
    public DmEnvHistoryModbusDataDto findById(Long id) {
        DmEnvHistoryModbusData dmEnvHistoryModbusData = dmEnvHistoryModbusDataRepository.findById(id).orElseGet(DmEnvHistoryModbusData::new);
        ValidationUtil.isNull(dmEnvHistoryModbusData.getId(),"DmEnvHistoryModbusData","id",id);
        return dmEnvHistoryModbusDataMapper.toDto(dmEnvHistoryModbusData);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public DmEnvHistoryModbusDataDto create(DmEnvHistoryModbusData resources) {
        Snowflake snowflake = IdUtil.createSnowflake(1, 1);
        resources.setId(snowflake.nextId()); 
        return dmEnvHistoryModbusDataMapper.toDto(dmEnvHistoryModbusDataRepository.save(resources));
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void update(DmEnvHistoryModbusData resources) {
        DmEnvHistoryModbusData dmEnvHistoryModbusData = dmEnvHistoryModbusDataRepository.findById(resources.getId()).orElseGet(DmEnvHistoryModbusData::new);
        ValidationUtil.isNull( dmEnvHistoryModbusData.getId(),"DmEnvHistoryModbusData","id",resources.getId());
        dmEnvHistoryModbusData.copy(resources);
        dmEnvHistoryModbusDataRepository.save(dmEnvHistoryModbusData);
    }

    @Override
    public void deleteAll(Long[] ids) {
        for (Long id : ids) {
            dmEnvHistoryModbusDataRepository.deleteById(id);
        }
    }

    @Override
    public void download(List<DmEnvHistoryModbusDataDto> all, HttpServletResponse response) throws IOException {
        List<Map<String, Object>> list = new ArrayList<>();
        for (DmEnvHistoryModbusDataDto dmEnvHistoryModbusData : all) {
            Map<String,Object> map = new LinkedHashMap<>();
            map.put(" cho",  dmEnvHistoryModbusData.getCho());
            map.put(" co2",  dmEnvHistoryModbusData.getCo2());
            map.put(" h",  dmEnvHistoryModbusData.getH());
            map.put(" pm10",  dmEnvHistoryModbusData.getPm10());
            map.put(" pm25",  dmEnvHistoryModbusData.getPm25());
            map.put(" t",  dmEnvHistoryModbusData.getT());
            map.put(" voc",  dmEnvHistoryModbusData.getVoc());
            map.put("关联对象id", dmEnvHistoryModbusData.getDeviceIdentifier());
            list.add(map);
        }
        FileUtil.downloadExcel(list, response);
    }
}