/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.envmonitor.historywarnconfig.rest;

import me.zhengjie.annotation.Log;
import me.zhengjie.modules.dm.envmonitor.historywarnconfig.domain.DmEnvHistoryWarnConfig;
import me.zhengjie.modules.dm.envmonitor.historywarnconfig.service.DmEnvHistoryWarnConfigService;
import me.zhengjie.modules.dm.envmonitor.historywarnconfig.service.dto.DmEnvHistoryWarnConfigQueryCriteria;
import org.springframework.data.domain.Pageable;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

/**
* @website https://el-admin.vip
* @author lr
* @date 2022-05-19
**/
@RestController
@RequiredArgsConstructor
@Api(tags = "告警配置管理")
@RequestMapping("/api/dmEnvHistoryWarnConfig")
public class DmEnvHistoryWarnConfigController {

    private final DmEnvHistoryWarnConfigService dmEnvHistoryWarnConfigService;

    @Log("导出数据")
    @ApiOperation("导出数据")
    @GetMapping(value = "/download")
    @PreAuthorize("@el.check('dmEnvHistoryWarnConfig:list')")
    public void download(HttpServletResponse response, DmEnvHistoryWarnConfigQueryCriteria criteria) throws IOException {
        dmEnvHistoryWarnConfigService.download(dmEnvHistoryWarnConfigService.queryAll(criteria), response);
    }

    @GetMapping
    @Log("查询告警配置")
    @ApiOperation("查询告警配置")
    @PreAuthorize("@el.check('dmEnvHistoryWarnConfig:list')")
    public ResponseEntity<Object> query(DmEnvHistoryWarnConfigQueryCriteria criteria, Pageable pageable){
        return new ResponseEntity<>(dmEnvHistoryWarnConfigService.queryAll(criteria,pageable),HttpStatus.OK);
    }

    @PostMapping
    @Log("新增告警配置")
    @ApiOperation("新增告警配置")
    @PreAuthorize("@el.check('dmEnvHistoryWarnConfig:add')")
    public ResponseEntity<Object> create(@Validated @RequestBody DmEnvHistoryWarnConfig resources){
        return new ResponseEntity<>(dmEnvHistoryWarnConfigService.create(resources),HttpStatus.CREATED);
    }

    @PutMapping
    @Log("修改告警配置")
    @ApiOperation("修改告警配置")
    @PreAuthorize("@el.check('dmEnvHistoryWarnConfig:edit')")
    public ResponseEntity<Object> update(@Validated @RequestBody DmEnvHistoryWarnConfig resources){
        dmEnvHistoryWarnConfigService.update(resources);
        return new ResponseEntity<>(HttpStatus.NO_CONTENT);
    }

    @Log("删除告警配置")
    @ApiOperation("删除告警配置")
    @PreAuthorize("@el.check('dmEnvHistoryWarnConfig:del')")
    @DeleteMapping
    public ResponseEntity<Object> delete(@RequestBody Long[] ids) {
        dmEnvHistoryWarnConfigService.deleteAll(ids);
        return new ResponseEntity<>(HttpStatus.OK);
    }
}