/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.envmonitor.icdevice.rest;

import me.zhengjie.annotation.Log;
import me.zhengjie.modules.dm.envmonitor.icdevice.domain.DmEnvIcDevice;
import me.zhengjie.modules.dm.envmonitor.icdevice.service.DmEnvIcDeviceService;
import me.zhengjie.modules.dm.envmonitor.icdevice.service.dto.DmEnvIcDeviceQueryCriteria;
import org.springframework.data.domain.Pageable;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

/**
* @website https://el-admin.vip
* @author shuai.huang
* @date 2021-03-30
**/
@RestController
@RequiredArgsConstructor
@Api(tags = "通信设备管理")
@RequestMapping("/api/dmEnvIcDevice")
public class DmEnvIcDeviceController {

    private final DmEnvIcDeviceService dmEnvIcDeviceService;

    @Log("导出数据")
    @ApiOperation("导出数据")
    @GetMapping(value = "/download")
    @PreAuthorize("@el.check('dmEnvIcDevice:list')")
    public void download(HttpServletResponse response, DmEnvIcDeviceQueryCriteria criteria) throws IOException {
        dmEnvIcDeviceService.download(dmEnvIcDeviceService.queryAll(criteria), response);
    }

    @GetMapping
    @Log("查询通信设备")
    @ApiOperation("查询通信设备")
    @PreAuthorize("@el.check('dmEnvIcDevice:list')")
    public ResponseEntity<Object> query(DmEnvIcDeviceQueryCriteria criteria, Pageable pageable){
        return new ResponseEntity<>(dmEnvIcDeviceService.queryAll(criteria,pageable),HttpStatus.OK);
    }

    @PostMapping
    @Log("新增通信设备")
    @ApiOperation("新增通信设备")
    @PreAuthorize("@el.check('dmEnvIcDevice:add')")
    public ResponseEntity<Object> create(@Validated @RequestBody DmEnvIcDevice resources){
        return new ResponseEntity<>(dmEnvIcDeviceService.create(resources),HttpStatus.CREATED);
    }

    @PutMapping
    @Log("修改通信设备")
    @ApiOperation("修改通信设备")
    @PreAuthorize("@el.check('dmEnvIcDevice:edit')")
    public ResponseEntity<Object> update(@Validated @RequestBody DmEnvIcDevice resources){
        dmEnvIcDeviceService.update(resources);
        return new ResponseEntity<>(HttpStatus.NO_CONTENT);
    }

    @Log("删除通信设备")
    @ApiOperation("删除通信设备")
    @PreAuthorize("@el.check('dmEnvIcDevice:del')")
    @DeleteMapping
    public ResponseEntity<Object> delete(@RequestBody Long[] ids) {
        dmEnvIcDeviceService.deleteAll(ids);
        return new ResponseEntity<>(HttpStatus.OK);
    }
}