/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.modbus.deviceStatus.service.impl;

import me.zhengjie.modules.dm.modbus.deviceStatus.domain.DmModbusDeviceStatus;
import me.zhengjie.utils.ValidationUtil;
import me.zhengjie.utils.FileUtil;
import lombok.RequiredArgsConstructor;
import me.zhengjie.modules.dm.modbus.deviceStatus.repository.DmModbusDeviceStatusRepository;
import me.zhengjie.modules.dm.modbus.deviceStatus.service.DmModbusDeviceStatusService;
import me.zhengjie.modules.dm.modbus.deviceStatus.service.dto.DmModbusDeviceStatusDto;
import me.zhengjie.modules.dm.modbus.deviceStatus.service.dto.DmModbusDeviceStatusQueryCriteria;
import me.zhengjie.modules.dm.modbus.deviceStatus.service.mapstruct.DmModbusDeviceStatusMapper;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import cn.hutool.core.lang.Snowflake;
import cn.hutool.core.util.IdUtil;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import me.zhengjie.utils.PageUtil;
import me.zhengjie.utils.QueryHelp;
import java.util.List;
import java.util.Map;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.LinkedHashMap;

/**
* @website https://el-admin.vip
* @description 服务实现
* @author wld
* @date 2022-05-26
**/
@Service
@RequiredArgsConstructor
public class DmModbusDeviceStatusServiceImpl implements DmModbusDeviceStatusService {

    private final DmModbusDeviceStatusRepository dmModbusDeviceStatusRepository;
    private final DmModbusDeviceStatusMapper dmModbusDeviceStatusMapper;

    @Override
    public Map<String,Object> queryAll(DmModbusDeviceStatusQueryCriteria criteria, Pageable pageable){
        Page<DmModbusDeviceStatus> page = dmModbusDeviceStatusRepository.findAll((root, criteriaQuery, criteriaBuilder) -> QueryHelp.getPredicate(root,criteria,criteriaBuilder),pageable);
        return PageUtil.toPage(page.map(dmModbusDeviceStatusMapper::toDto));
    }

    @Override
    public List<DmModbusDeviceStatusDto> queryAll(DmModbusDeviceStatusQueryCriteria criteria){
        return dmModbusDeviceStatusMapper.toDto(dmModbusDeviceStatusRepository.findAll((root, criteriaQuery, criteriaBuilder) -> QueryHelp.getPredicate(root,criteria,criteriaBuilder)));
    }

    @Override
    @Transactional
    public DmModbusDeviceStatusDto findById(Long id) {
        DmModbusDeviceStatus dmModbusDeviceStatus = dmModbusDeviceStatusRepository.findById(id).orElseGet(DmModbusDeviceStatus::new);
        ValidationUtil.isNull(dmModbusDeviceStatus.getId(),"DmModbusDeviceStatus","id",id);
        return dmModbusDeviceStatusMapper.toDto(dmModbusDeviceStatus);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public DmModbusDeviceStatusDto create(DmModbusDeviceStatus resources) {
        Snowflake snowflake = IdUtil.createSnowflake(1, 1);
        resources.setId(snowflake.nextId()); 
        return dmModbusDeviceStatusMapper.toDto(dmModbusDeviceStatusRepository.save(resources));
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void update(DmModbusDeviceStatus resources) {
        DmModbusDeviceStatus dmModbusDeviceStatus = dmModbusDeviceStatusRepository.findById(resources.getId()).orElseGet(DmModbusDeviceStatus::new);
        ValidationUtil.isNull( dmModbusDeviceStatus.getId(),"DmModbusDeviceStatus","id",resources.getId());
        dmModbusDeviceStatus.copy(resources);
        dmModbusDeviceStatusRepository.save(dmModbusDeviceStatus);
    }

    @Override
    public void deleteAll(Long[] ids) {
        for (Long id : ids) {
            dmModbusDeviceStatusRepository.deleteById(id);
        }
    }

    @Override
    public void download(List<DmModbusDeviceStatusDto> all, HttpServletResponse response) throws IOException {
        List<Map<String, Object>> list = new ArrayList<>();
        for (DmModbusDeviceStatusDto dmModbusDeviceStatus : all) {
            Map<String,Object> map = new LinkedHashMap<>();
            map.put("设备id", dmModbusDeviceStatus.getDeviceId());
            map.put("设备状态", dmModbusDeviceStatus.getDeviceStatus());
            map.put("创建时间", dmModbusDeviceStatus.getCreateTime());
            list.add(map);
        }
        FileUtil.downloadExcel(list, response);
    }
}