/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.modbus.drive.domain;

import com.alibaba.fastjson.annotation.JSONField;
import com.alibaba.fastjson.serializer.ToStringSerializer;
import lombok.Data;
import cn.hutool.core.bean.BeanUtil;
import io.swagger.annotations.ApiModelProperty;
import cn.hutool.core.bean.copier.CopyOptions;
import javax.persistence.*;
import javax.persistence.CascadeType;
import javax.validation.constraints.*;
import javax.persistence.Entity;
import javax.persistence.Table;

import me.zhengjie.base.BaseEntity;
import me.zhengjie.modules.dm.modbus.channel.domain.DmModbusChannel;
import org.hibernate.annotations.*;
import java.sql.Timestamp;
import java.io.Serializable;
import java.util.List;
import java.util.Set;

/**
* @website https://el-admin.vip
* @description /
* @author wld
* @date 2022-05-20
**/
@Entity
@Data
@Table(name="dm_modbus_drive")
public class DmModbusDrive extends BaseEntity implements Serializable {

    @Id
    @Column(name = "drive_id")
    @ApiModelProperty(value = "驱动id")
    @JSONField(serializeUsing = ToStringSerializer.class)
    private Long driveId;

    @Column(name = "drive_name",nullable = false)
    @NotBlank
    @ApiModelProperty(value = "驱动名称")
    private String driveName;

    @Column(name = "name",nullable = false)
    @NotBlank
    @ApiModelProperty(value = "名称")
    private String name;

    @Column(name = "poll_time",nullable = false)
    @NotNull
    @ApiModelProperty(value = "轮询时间(毫秒)")
    @JSONField(serializeUsing = ToStringSerializer.class)
    private Long pollTime;

    @OneToMany(fetch = FetchType.EAGER)
    @JoinColumn(name = "drive_id")
    private Set<DmModbusChannel> channels;

    public void copy(DmModbusDrive source){
        BeanUtil.copyProperties(source,this, CopyOptions.create().setIgnoreNullValue(true));
    }
}