/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.modbus.group.domain;

import com.alibaba.fastjson.annotation.JSONField;
import com.alibaba.fastjson.serializer.ToStringSerializer;
import lombok.Data;
import cn.hutool.core.bean.BeanUtil;
import io.swagger.annotations.ApiModelProperty;
import cn.hutool.core.bean.copier.CopyOptions;
import javax.persistence.*;
import javax.persistence.CascadeType;
import javax.validation.constraints.*;
import javax.persistence.Entity;
import javax.persistence.Table;

import me.zhengjie.base.BaseEntity;
import me.zhengjie.modules.dm.modbus.data.domain.DmModbusData;
import me.zhengjie.modules.dm.modbus.device.domain.DmModbusDevice;
import org.hibernate.annotations.*;
import java.sql.Timestamp;
import java.io.Serializable;
import java.util.List;

/**
* @website https://el-admin.vip
* @description /
* @author wld
* @date 2022-05-21
**/
@Entity
@Data
@Table(name="dm_modbus_group")
public class DmModbusGroup extends BaseEntity implements Serializable {

    @Id
    @Column(name = "group_id")
    @ApiModelProperty(value = "组id")
    @JSONField(serializeUsing = ToStringSerializer.class)
    private Long groupId;

    @Column(name = "group_name",nullable = false)
    @NotBlank
    @ApiModelProperty(value = "组名称")
    private String groupName;

    @Column(name = "device_id",nullable = false)
    @NotNull
    @ApiModelProperty(value = "设备关联id")
    @JSONField(serializeUsing = ToStringSerializer.class)
    private Long deviceId;

    @ApiModelProperty(value = "通过分组id关联数据")
    @OneToMany(fetch = FetchType.EAGER)
    @JoinColumn(name = "group_id")
    private List<DmModbusData> dmModbusData;

    public void copy(DmModbusGroup source){
        BeanUtil.copyProperties(source,this, CopyOptions.create().setIgnoreNullValue(true));
    }
}