/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.modbus.group.rest;

import me.zhengjie.annotation.Log;
import me.zhengjie.modules.dm.modbus.group.domain.DmModbusGroup;
import me.zhengjie.modules.dm.modbus.group.service.DmModbusGroupService;
import me.zhengjie.modules.dm.modbus.group.service.dto.DmModbusGroupQueryCriteria;
import org.springframework.data.domain.Pageable;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

/**
* @website https://el-admin.vip
* @author wld
* @date 2022-05-21
**/
@RestController
@RequiredArgsConstructor
@Api(tags = "分组管理管理")
@RequestMapping("/api/dmModbusGroup")
public class DmModbusGroupController {

    private final DmModbusGroupService dmModbusGroupService;

    @Log("导出数据")
    @ApiOperation("导出数据")
    @GetMapping(value = "/download")
    @PreAuthorize("@el.check('dmModbusGroup:list')")
    public void download(HttpServletResponse response, DmModbusGroupQueryCriteria criteria) throws IOException {
        dmModbusGroupService.download(dmModbusGroupService.queryAll(criteria), response);
    }

    @GetMapping
    @Log("查询分组管理")
    @ApiOperation("查询分组管理")
    @PreAuthorize("@el.check('dmModbusGroup:list')")
    public ResponseEntity<Object> query(DmModbusGroupQueryCriteria criteria, Pageable pageable){
        return new ResponseEntity<>(dmModbusGroupService.queryAll(criteria,pageable),HttpStatus.OK);
    }

    @PostMapping
    @Log("新增分组管理")
    @ApiOperation("新增分组管理")
    @PreAuthorize("@el.check('dmModbusGroup:add')")
    public ResponseEntity<Object> create(@Validated @RequestBody DmModbusGroup resources){
        return new ResponseEntity<>(dmModbusGroupService.create(resources),HttpStatus.CREATED);
    }

    @PutMapping
    @Log("修改分组管理")
    @ApiOperation("修改分组管理")
    @PreAuthorize("@el.check('dmModbusGroup:edit')")
    public ResponseEntity<Object> update(@Validated @RequestBody DmModbusGroup resources){
        dmModbusGroupService.update(resources);
        return new ResponseEntity<>(HttpStatus.NO_CONTENT);
    }

    @Log("删除分组管理")
    @ApiOperation("删除分组管理")
    @PreAuthorize("@el.check('dmModbusGroup:del')")
    @DeleteMapping
    public ResponseEntity<Object> delete(@RequestBody Long[] ids) {
        dmModbusGroupService.deleteAll(ids);
        return new ResponseEntity<>(HttpStatus.OK);
    }
}